@@ -12,7 +12,7 @@
 #define BTMPX_FILE "/var/log/btmp"
 #endif
 
-int _count_utmpx(const char *file,
+int count_utmpx(const char *file,
                 const char *user,
                 struct timeval *since,
                 struct utmpx *current,
