@@ -283,7 +283,7 @@ func (u *User) getSenderDBus(sender dbus.Sender) string {
 		return ""
 	}
 	proc := procfs.Process(pid)
-	exe, err := proc.TrustedExe()
+	exe, err := proc.Exe()
 	if err != nil {
 		logger.Warning(err)
 		return ""
@@ -530,7 +530,7 @@ func (u *User) checkIsControlCenter(sender dbus.Sender) bool {
 	}
 
 	p := procfs.Process(pid)
-	exe, err := p.TrustedExe()
+	exe, err := p.Exe()
 	if err != nil {
 		logger.Warning(err)
 		return false
@@ -551,7 +551,7 @@ func (u *User) checkIsDeepinDaemon(sender dbus.Sender) bool {
 	}
 
 	p := procfs.Process(pid)
-	exe, err := p.TrustedExe()
+	exe, err := p.Exe()
 	if err != nil {
 		logger.Warning(err)
 		return false
@@ -1035,15 +1035,15 @@ func (u *User) setQuickLogin(enabled bool) *dbus.Error {
 		return nil
 	}
 
-	// 先打开总开关
+	// 先打开lightdm的quicklogin-enabled
 	if enabled {
-		accountsManager := getAccountsManager()
-		if accountsManager == nil {
-			return dbusutil.ToError(errors.New("get accounts manager failed"))
-		}
-		err := accountsManager.setDConfigQuickLoginEnabled(true)
+		mainEnable, err := users.GetLightDMQuickLoginEnabled()
 		if err != nil {
-			return dbusutil.ToError(fmt.Errorf("set greeter dconfig enableQuickLogin failed: %v", err))
+			return dbusutil.ToError(errors.New("get lightdm quick login failed"))
+		}
+
+		if !mainEnable {
+			users.SetLightDMQuickLoginEnabled(enabled)
 		}
 	}
 
