@@ -18,35 +18,24 @@ import (
 	"github.com/linuxdeepin/go-lib/strv"
 
 	dbus "github.com/godbus/dbus/v5"
+	"github.com/linuxdeepin/dde-daemon/common/dconfig"
 	"github.com/linuxdeepin/dde-daemon/common/dsync"
 	notifications "github.com/linuxdeepin/go-dbus-factory/session/org.freedesktop.notifications"
 	systemd1 "github.com/linuxdeepin/go-dbus-factory/system/org.freedesktop.systemd1"
-	gio "github.com/linuxdeepin/go-gir/gio-2.0"
 	"github.com/linuxdeepin/go-lib/dbusutil"
-	"github.com/linuxdeepin/go-lib/dbusutil/gsprop"
 	. "github.com/linuxdeepin/go-lib/gettext"
 	"github.com/linuxdeepin/go-lib/pulse"
 	"golang.org/x/xerrors"
 )
 
 const (
-	gsSchemaAudio                 = "com.deepin.dde.audio"
-	gsKeyFirstRun                 = "first-run"
-	gsKeyInputVolume              = "input-volume"
-	gsKeyOutputVolume             = "output-volume"
-	gsKeyHeadphoneOutputVolume    = "headphone-output-volume"
-	gsKeyHeadphoneUnplugAutoPause = "headphone-unplug-auto-pause"
-	gsKeyVolumeIncrease           = "volume-increase"
-
-	gsKeyReduceNoise              = "reduce-input-noise"
-	gsKeyOutputAutoSwitchCountMax = "output-auto-switch-count-max"
-
-	gsSchemaControlCenter = "com.deepin.dde.control-center"
-	gsKeyDeviceManager    = "device-manage"
-
-	gsSchemaSoundEffect  = "com.deepin.dde.sound-effect"
 	gsKeyEnabled         = "enabled"
-	gsKeyDisableAutoMute = "disable-auto-mute"
+	dconfigSoundEffectId = "org.deepin.dde.daemon.soundeffect"
+	dconfigDaemonAppId   = "org.deepin.dde.daemon"
+	dconfigAudioId       = "org.deepin.dde.daemon.audio"
+
+	dconfigDccAppid = "org.deepin.dde.control-center"
+	dconfigSoundId  = "org.deepin.dde.control-center.sound"
 
 	dbusServiceName = "org.deepin.dde.Audio1"
 	dbusPath        = "/org/deepin/dde/Audio1"
@@ -63,6 +52,8 @@ const (
 	increaseMaxVolume = 1.5
 	normalMaxVolume   = 1.0
 
+	dsgkeySoundShowDeviceManager = "showDeviceManager"
+
 	dsgkeyPausePlayer             = "pausePlayer"
 	dsgKeyAutoSwitchPort          = "autoSwitchPort"
 	dsgKeyBluezModeFilterList     = "bluezModeFilterList"
@@ -73,6 +64,15 @@ const (
 	dsgKeyBluezModeDefault        = "bluezModeDefault"
 	dsgKeyMonoEnabled             = "monoEnabled"
 
+	dsgKeyFirstRun                 = "firstRun"
+	dsgKeyInputVolume              = "inputVolume"
+	dsgKeyOutputVolume             = "outputVolume"
+	dsgKeyHeadphoneOutputVolume    = "headphoneOutputVolume"
+	dsgKeyHeadphoneUnplugAutoPause = "headphoneUnplugAutoPause"
+	dsgKeyVolumeIncrease           = "volumeIncrease"
+	dsgKeyOutputAutoSwitchCountMax = "outputAutoSwitchCountMax"
+	dsgKeyDisableAutoMute          = "disableAutoMute"
+
 	changeIconStart    = "notification-change-start"
 	changeIconFailed   = "notification-change-failed"
 	changeIconFinished = "notification-change-finished"
@@ -148,7 +148,7 @@ type Audio struct {
 	AudioServerState       bool     // 音频服务状态
 
 	// dbusutil-gen: ignore
-	IncreaseVolume gsprop.Bool `prop:"access:rw"`
+	IncreaseVolume dconfig.Bool `prop:"access:rw"`
 
 	PausePlayer bool `prop:"access:rw"`
 
@@ -164,7 +164,9 @@ type Audio struct {
 
 	headphoneUnplugAutoPause bool
 
-	settings  *gio.Settings
+	audioDConfig    *dconfig.DConfig
+	dccSoundDconfig *dconfig.DConfig
+
 	ctx       *pulse.Context
 	eventChan chan *pulse.Event
 	stateChan chan int
@@ -208,19 +210,13 @@ type Audio struct {
 	outputAutoSwitchCount    int
 	outputAutoSwitchCountMax int
 	// 自动端口切换
-	enableAutoSwitchPort    bool
-	controlCenterGsSettings *gio.Settings
-	// 控制中心-声音-设备管理 是否显示
-	controlCenterDeviceManager gsprop.Bool `prop:"access:rw"`
+	enableAutoSwitchPort bool
 
-	systemSigLoop *dbusutil.SignalLoop
+	// 控制中心-声音-设备管理 是否显示
+	controlCenterDeviceManager dconfig.Bool
 	// 用来进一步断是否需要暂停播放的信息
 	misc uint32
 
-	callbackLocker        sync.Mutex
-	defaultSinkCallback   func(sink *pulse.Sink)
-	defaultSourceCallback func(source *pulse.Source)
-
 	// nolint
 	signals *struct {
 		PortEnabledChanged struct {
@@ -231,15 +227,6 @@ type Audio struct {
 	}
 }
 
-func isStringInSlice(list []string, str string) bool {
-	for _, v := range list {
-		if v == str {
-			return true
-		}
-	}
-	return false
-}
-
 func newAudio(service *dbusutil.Service) *Audio {
 	a := &Audio{
 		service:          service,
@@ -249,33 +236,43 @@ func newAudio(service *dbusutil.Service) *Audio {
 		AudioServerState: AudioStateChanged,
 	}
 
-	a.settings = gio.NewSettings(gsSchemaAudio)
-	a.settings.Reset(gsKeyInputVolume)
-	a.settings.Reset(gsKeyOutputVolume)
-	a.settings.Reset(gsKeyHeadphoneOutputVolume)
-	a.IncreaseVolume.Bind(a.settings, gsKeyVolumeIncrease)
+	var err error
+	a.audioDConfig, err = dconfig.NewDConfig(dconfigDaemonAppId, dconfigAudioId, "")
+	if err != nil {
+		logger.Warningf("NewAudioDConfig failed: %v", err)
+		return a
+	}
+
+	a.dccSoundDconfig, err = dconfig.NewDConfig(dconfigDccAppid, dconfigSoundId, "")
+	if err != nil {
+		logger.Warningf("NewDccDConfig failed: %v", err)
+	}
+
+	a.audioDConfig.Reset(dsgKeyInputVolume)
+	a.audioDConfig.Reset(dsgKeyOutputVolume)
+	a.audioDConfig.Reset(dsgKeyHeadphoneOutputVolume)
+	a.IncreaseVolume.Bind(a.audioDConfig, dsgKeyVolumeIncrease)
 	a.PausePlayer = false
 	a.ReduceNoise = false
 	a.emitPropChangedReduceNoise(a.ReduceNoise)
 	a.CurrentAudioServer = a.getCurrentAudioServer()
-	a.headphoneUnplugAutoPause = a.settings.GetBoolean(gsKeyHeadphoneUnplugAutoPause)
-	a.outputAutoSwitchCountMax = int(a.settings.GetInt(gsKeyOutputAutoSwitchCountMax))
+	a.headphoneUnplugAutoPause, err = a.audioDConfig.GetValueBool(dsgKeyHeadphoneUnplugAutoPause)
+	if err != nil {
+		logger.Warningf("Get headphoneUnplugAutoPause ValueBool failed: %v", err)
+	}
+	a.outputAutoSwitchCountMax, err = a.audioDConfig.GetValueInt(dsgKeyOutputAutoSwitchCountMax)
+	if err != nil {
+		logger.Warningf("Get outputAutoSwitchCountMax ValueInt failed: %v", err)
+	}
 	if a.IncreaseVolume.Get() {
 		a.MaxUIVolume = increaseMaxVolume
 	} else {
 		a.MaxUIVolume = normalMaxVolume
 	}
 	gMaxUIVolume = a.MaxUIVolume
-	a.listenGSettingVolumeIncreaseChanged()
 
-	if isStringInSlice(gio.SettingsListSchemas(), gsSchemaControlCenter) {
-		a.controlCenterGsSettings = gio.NewSettings(gsSchemaControlCenter)
-		if isStringInSlice(a.controlCenterGsSettings.ListKeys(), gsKeyDeviceManager) {
-			a.controlCenterDeviceManager.Bind(a.controlCenterGsSettings, gsKeyDeviceManager)
-			a.listenGSettingDeviceManageChanged()
-		}
-	} else {
-		logger.Warning(" [newAudio] gschemas file not exist : /usr/share/glib-2.0/schemas/com.deepin.dde.control-center.gschema.xml")
+	if a.dccSoundDconfig != nil {
+		a.controlCenterDeviceManager.Bind(a.dccSoundDconfig, dsgkeySoundShowDeviceManager)
 	}
 
 	a.sessionSigLoop = dbusutil.NewSignalLoop(service.Conn(), 10)
@@ -806,6 +803,9 @@ func (a *Audio) autoPause() {
 	if !a.shouldAutoPause() {
 		return
 	}
+	if a.defaultSink == nil {
+		return
+	}
 
 	var port pulse.CardPortInfo
 	card, err := a.ctx.GetCard(a.defaultSink.Card)
@@ -833,53 +833,98 @@ func (a *Audio) autoPause() {
 // 同一张声卡可能存在多个端口，用户也可能切换过端口
 // 通过PriorityManager获取最高优先级对应的卡，然后根据配置获取期望端口
 func (a *Audio) tryGetPreferOutPut() PriorityPort {
-	// 获取PriorityManager获取最高优先级的端口以及对应的声卡
-	firstOutput := GetPriorityManager().Output.GetTheFirstPort()
-	// 获取声卡配置期望的端口
-	preferPort := GetConfigKeeper().GetCardPreferPort(firstOutput.CardName)
-	if preferPort == "" {
-		card, err := a.cards.getByName(firstOutput.CardName)
-		if err != nil {
-			logger.Warning(err)
-			return firstOutput
-		}
-		// TODO: 这个逻辑有问题，下次来修改
-		for _, preferProfile := range card.Profiles {
-			if preferProfile.Available == 0 {
-				continue
-			}
+	for _, pp := range GetPriorityManager().Output.Ports {
+		// 获取声卡配置期望的端口
+		cc, pc := GetConfigKeeper().GetCardAndPortConfig(pp.CardName, pp.PortName)
+		logger.Debugf("tryGetPreferOutPut: card=%+v, port=%+v", cc, pc)
+		if !pc.Enabled {
+			continue
+		} else {
+			prefrePort := cc.PreferPort
+			preferProfile := cc.PreferProfile
 
-			for _, port := range card.Ports {
-				if port.Available != pulse.AvailableTypeNo &&
-					port.Direction == pulse.DirectionSink &&
-					port.Profiles.Exists(preferProfile.Name) {
-					logger.Infof("tryGetPreferOutPut:prefer port %s, card %s", port.Name, card.core.Name)
-					return PriorityPort{
-						CardName: firstOutput.CardName,
-						PortName: port.Name,
-						PortType: GetPortType(firstOutput.CardName, port.Name),
+			// 查询当前声卡的优选端口
+			// 如果期望端口为空，说明当前声卡没有设置够端口，直接用默认优先级
+			if preferProfile == "" || cc.PreferPort == "" {
+				card, err := a.cards.getByName(cc.Name)
+				if err != nil {
+					logger.Warning(err)
+					continue
+				}
+				for _, profile := range card.Profiles {
+					if profile.Available == 0 {
+						continue
 					}
 
+					// TODO: 优先级配置文件需要优化，当前逻辑过于复杂
+					// 因为同一设备的不同端口，没有先后顺序，比如蓝牙设备的优先级：a2dp > handset
+					// 但是在priority中，a2dp和handset的优先级是相同的，且先后顺序不定，因此需要通过profile来判断优先级。
+					for _, port := range card.Ports {
+						_, pc2 := GetConfigKeeper().GetCardAndPortConfig(card.Name, port.Name)
+						if port.Available == pulse.AvailableTypeNo ||
+							!pc2.Enabled ||
+							port.Direction == pulse.DirectionSource {
+							continue
+						}
+						if port.Profiles.Exists(profile.Name) {
+							logger.Debugf("tryGetPreferOutPut:prefer port %s, card %s", port.Name, card.core.Name)
+							return PriorityPort{
+								CardName: cc.Name,
+								PortName: port.Name,
+								PortType: DetectPortType(card.core, &port),
+							}
+						}
+					}
+				}
+			} else {
+				card, err := a.cards.getByName(cc.Name)
+				if err != nil {
+					logger.Warning(err)
+					continue
+				}
+
+				// 先判断期望端口是否可用，如果不可用，查找当前声卡其他端口是否可用
+				if prefrePort != "" {
+					_, pc2 := GetConfigKeeper().GetCardAndPortConfig(cc.Name, prefrePort)
+					if pc2.Enabled {
+						port, err := card.Ports.Get(prefrePort, pulse.DirectionSink)
+						if err != nil {
+							logger.Warning(err)
+							continue
+						}
+						logger.Debugf("tryGetPreferOutPut:prefer port %s, card %s", cc.Name, prefrePort)
+						return PriorityPort{
+							CardName: cc.Name,
+							PortName: pc2.Name,
+							PortType: DetectPortType(card.core, &port),
+						}
+					}
+				}
+				for _, port := range card.Ports {
+					if port.Available == pulse.AvailableTypeNo {
+						continue
+					}
+					_, pc2 := GetConfigKeeper().GetCardAndPortConfig(card.Name, port.Name)
+					if !pc2.Enabled {
+						continue
+					}
+
+					if port.Profiles.Exists(preferProfile) && port.Direction == pulse.DirectionSink {
+						return PriorityPort{
+							CardName: cc.Name,
+							PortName: port.Name,
+							PortType: DetectPortType(card.core, &port),
+						}
+					}
 				}
 			}
 		}
-
 	}
-	if firstOutput.PortName == preferPort {
-		logger.Infof("tryGetPreferOutPut:prefer output %v", firstOutput)
-		return firstOutput
+	return PriorityPort{
+		"",
+		"",
+		PortTypeInvalid,
 	}
-	// 查找PriorityManager中对应端口
-	for _, pp := range GetPriorityManager().Output.Ports {
-		if pp.PortName == preferPort {
-			logger.Infof("tryGetPreferOutPut:prefer output %v", *pp)
-			return *pp
-		}
-	}
-
-	// 正常情况下，在PriorityManager是一定存在的，如果不存在，则返回firstOutput
-	logger.Warning("prefer port not found, maybe something wrong", firstOutput)
-	return firstOutput
 }
 
 func (a *Audio) refreshDefaultSinkSource() {
@@ -901,6 +946,10 @@ func (a *Audio) refreshDefaultSinkSource() {
 	}
 	// GetPriorityManager中的port是refresh之后的，正常情况下一定存在的
 	// pipewire sink变化的时候，可能其sink列表中不存在当前设置的端口所对应的sink，说明pipewire的切换还未完成
+	if a.defaultSink == nil {
+		logger.Warning("defulat sink is nil")
+		return
+	}
 	if sinkInfo.Card != card.Id || sinkInfo.ActivePort.Name != preferPort.PortName {
 		// 查找声卡所对应的sink是否存在
 		var sink *Sink = nil
@@ -982,7 +1031,8 @@ func (a *Audio) refresh() {
 }
 
 func (a *Audio) init() error {
-	if a.settings.GetBoolean(gsKeyDisableAutoMute) {
+	disableAutoMuteValue, _ := a.audioDConfig.GetValueBool(dsgKeyDisableAutoMute)
+	if disableAutoMuteValue {
 		err := disableAutoMuteMode()
 		if err != nil {
 			logger.Warning(err)
@@ -1073,11 +1123,14 @@ func (a *Audio) init() error {
 	go a.handleStateChanged()
 	logger.Debug("init done")
 
-	firstRun := a.settings.GetBoolean(gsKeyFirstRun)
+	firstRun, err := a.audioDConfig.GetValueBool(dsgKeyFirstRun)
+	if err != nil {
+		logger.Warning(err)
+	}
 	if firstRun {
 		logger.Info("first run, Will remove old audio config")
 		removeConfig()
-		a.settings.SetBoolean(gsKeyFirstRun, false)
+		a.audioDConfig.SetValue(dsgKeyFirstRun, false)
 	}
 
 	if !a.needAutoSwitchOutputPort() {
@@ -1088,14 +1141,13 @@ func (a *Audio) init() error {
 		a.resumeSourceConfig(a.defaultSource, isPhysicalDevice(a.defaultSourceName))
 	}
 
-	// 自动切换会在切换后触发配置恢复
 	a.autoSwitchPort()
 
 	a.fixActivePortNotAvailable()
-	a.moveSinkInputsToDefaultSink()
+	a.moveSinkInputsToSink(nil)
 
 	// 蓝牙支持的模式
-	a.setPropBluetoothAudioModeOpts([]string{"a2dp", "headset", "handsfree"})
+	a.refreshBluetoothOpts()
 
 	return nil
 }
@@ -1141,20 +1193,28 @@ func (a *Audio) destroyCtxRelated() {
 }
 
 func (a *Audio) destroy() {
-	a.settings.Unref()
 	a.sessionSigLoop.Stop()
-	a.systemSigLoop.Stop()
 	a.syncConfig.Destroy()
 	a.destroyCtxRelated()
 }
 
 func (a *Audio) initDefaultVolumes() {
-	inVolumePer := float64(a.settings.GetInt(gsKeyInputVolume)) / 100.0
-	outVolumePer := float64(a.settings.GetInt(gsKeyOutputVolume)) / 100.0
-	headphoneOutVolumePer := float64(a.settings.GetInt(gsKeyHeadphoneOutputVolume)) / 100.0
-	defaultInputVolume = inVolumePer
-	defaultOutputVolume = outVolumePer
-	defaultHeadphoneOutputVolume = headphoneOutVolumePer
+	inVolumePerValue, err := a.audioDConfig.GetValueFloat64(dsgKeyInputVolume)
+	if err != nil {
+		logger.Warning(err)
+	}
+	outVolumePerValue, err := a.audioDConfig.GetValueFloat64(dsgKeyOutputVolume)
+	if err != nil {
+		logger.Warning(err)
+	}
+	headphoneOutVolumePerValue, err := a.audioDConfig.GetValueFloat64(dsgKeyHeadphoneOutputVolume)
+	if err != nil {
+		logger.Warning(err)
+	}
+
+	defaultInputVolume = inVolumePerValue / 100.0
+	defaultOutputVolume = outVolumePerValue / 100.0
+	defaultHeadphoneOutputVolume = headphoneOutVolumePerValue / 100.0
 }
 
 func (a *Audio) findSinkByCardIndexPortName(cardId uint32, portName string) *pulse.Sink {
@@ -1184,7 +1244,7 @@ func (a *Audio) SetPort(cardId uint32, portName string, direction int32) *dbus.E
 		return dbusutil.ToError(fmt.Errorf("card idx: %d, port name: %q is disabled", cardId, portName))
 	}
 
-	err := a.setPort(cardId, portName, int(direction))
+	err := a.setPort(cardId, portName, int(direction), false)
 	if err != nil {
 		logger.Warning(err)
 		return dbusutil.ToError(err)
@@ -1248,6 +1308,14 @@ func (a *Audio) SetPortEnabled(cardId uint32, portName string, enabled bool) *db
 	a.setPropCards(a.cards.string())
 	a.setPropCardsWithoutUnavailable(a.cards.stringWithoutUnavailable())
 	GetPriorityManager().SetPorts(a.cards)
+	card, err := a.cards.get(cardId)
+	if err == nil {
+		for _, port := range card.Ports {
+			if port.Name == portName && port.Profiles.Exists(card.ActiveProfile.Name) && port.Direction == pulse.DirectionSink {
+				GetConfigKeeper().SetProfile(card.Name, "")
+			}
+		}
+	}
 	a.autoSwitchPort()
 
 	sinks := a.findSinks(cardId, portName)
@@ -1271,7 +1339,10 @@ func (a *Audio) IsPortEnabled(cardId uint32, portName string) (enabled bool, bus
 	return portConfig.Enabled, nil
 }
 
-func (a *Audio) setPort(cardId uint32, portName string, direction int) error {
+// setPort: 设置端口，auto为true表示自动切换，false表示手动切换
+// 手动切换场景需要设置期望端口，用于恢复配置使用（保证禁用启用端口的正常）
+// 设置声卡的期望配置文件，是用于自动切换是是否达到期望状态，防止频繁切换
+func (a *Audio) setPort(cardId uint32, portName string, direction int, auto bool) error {
 	// 获取声卡信息
 	card, err := a.ctx.GetCard(cardId)
 	if err != nil {
@@ -1290,7 +1361,20 @@ func (a *Audio) setPort(cardId uint32, portName string, direction int) error {
 	}
 
 	// 端口不在当前配置文件中，需要切换配置文件
-	return a.setPortWithProfileSwitch(card, portName, direction)
+	profile := a.getPreferProfile(card, portName, direction)
+	if profile != "" {
+		// 切换配置文件
+		logger.Debugf("set profile: %s %s %s", card.Name, portName, profile)
+		GetConfigKeeper().SetProfile(card.Name, profile)
+		if direction == pulse.DirectionSink && !auto {
+			// 手动设置端口的场景，设置期望端口
+			GetConfigKeeper().SetCardPreferPort(card.Name, portName)
+		}
+		card.SetProfile(profile)
+	} else {
+		return fmt.Errorf("set port failed: get profile is empty")
+	}
+	return nil
 }
 
 // setPortDirectly 直接设置端口，无需切换配置文件
@@ -1347,12 +1431,13 @@ func (a *Audio) setSourcePortDirectly(cardId uint32, portName string) error {
 	return nil
 }
 
-// setPortWithProfileSwitch 通过切换配置文件来设置端口
-func (a *Audio) setPortWithProfileSwitch(card *pulse.Card, portName string, direction int) error {
+// getPreferProfile 通过切换配置文件来设置端口
+func (a *Audio) getPreferProfile(card *pulse.Card, portName string, direction int) string {
 	// 获取端口信息
 	port, err := card.Ports.Get(portName, direction)
 	if err != nil {
-		return err
+		logger.Warning(err)
+		return ""
 	}
 
 	// 查询当前端口的最高优先级的配置文件
@@ -1360,115 +1445,11 @@ func (a *Audio) setPortWithProfileSwitch(card *pulse.Card, portName string, dire
 	if firstProfile == "" {
 		firstProfile = port.Profiles.SelectProfile()
 		if firstProfile == "" {
-			return fmt.Errorf("no profile found for card %s and port %s", card.Name, portName)
-		}
-	}
-
-	// 设置回调函数，当对应的sink/source创建完成后，设置默认sink/source
-	a.setupPortCallback(card.Index, portName, direction)
-
-	// 切换配置文件
-	logger.Debugf("set profile: %s %s %s", card.Name, portName, firstProfile)
-	GetConfigKeeper().SetProfile(card.Name, portName, firstProfile)
-	card.SetProfile(firstProfile)
-
-	return nil
-}
-
-// setupPortCallback 设置端口切换的回调函数
-func (a *Audio) setupPortCallback(cardId uint32, portName string, direction int) {
-	if direction == pulse.DirectionSink {
-		a.setupSinkCallback(cardId, portName)
-	} else {
-		a.setupSourceCallback(cardId, portName)
-	}
-}
-
-// setupSinkCallback 设置输出端口的回调函数
-func (a *Audio) setupSinkCallback(cardId uint32, portName string) {
-	// 检查是否已经存在对应的sink
-	if a.findSinkByCardIndexPortName(cardId, portName) != nil {
-		return
-	}
-
-	a.callbackLocker.Lock()
-	defer a.callbackLocker.Unlock()
-	retry := 0
-	a.defaultSinkCallback = func(sink *pulse.Sink) {
-		logger.Warning("card Id check:", sink.Card, cardId)
-		// 连续多次都没有添加目标sink，说明切换可能失败了，不在尝试，否则影响自动切换
-		retry++
-		if retry > 10 {
-			logger.Warning("retry too many times, skip")
-			a.defaultSinkCallback = nil
-			return
-		}
-		if sink.Card != cardId {
-			return
-		}
-		logger.Warning("active port check:", sink.ActivePort.Name, portName)
-		// 检查sink的活跃端口是否为目标端口
-		if sink.ActivePort.Name == portName {
-			logger.Debugf("set default sink: %s, %s", sink.Name, portName)
-			a.ctx.SetDefaultSink(sink.Name)
-			a.defaultSinkCallback = nil
-			return
-		}
-
-		// 检查sink的端口列表中是否包含目标端口
-		for _, port := range sink.Ports {
-			logger.Warning("search prot:", port, portName)
-			if port.Name == portName {
-				logger.Debugf("set default sink: %s, %s", sink.Name, portName)
-				a.ctx.SetSinkPortByIndex(sink.Index, portName)
-				a.ctx.SetDefaultSink(sink.Name)
-				a.defaultSinkCallback = nil
-				return
-			}
-		}
-	}
-}
-
-// setupSourceCallback 设置输入端口的回调函数
-func (a *Audio) setupSourceCallback(cardId uint32, portName string) {
-	// 检查是否已经存在对应的source
-	if a.findSourceByCardIndexPortName(cardId, portName) != nil {
-		return
-	}
-
-	a.callbackLocker.Lock()
-	defer a.callbackLocker.Unlock()
-	retry := 0
-	a.defaultSourceCallback = func(source *pulse.Source) {
-		retry++
-		if retry > 10 {
-			logger.Warning("retry too many times, skip")
-			a.defaultSourceCallback = nil
-			return
-		}
-		if source.Card != cardId {
-			return
-		}
-
-		// 检查source的活跃端口是否为目标端口
-		if source.ActivePort.Name == portName {
-			logger.Debugf("set default source: %s, %s", source.Name, portName)
-			a.ctx.SetDefaultSource(source.Name)
-			a.defaultSourceCallback = nil
-			return
-		}
-
-		// 检查source的端口列表中是否包含目标端口
-		for _, port := range source.Ports {
-			if port.Name == portName {
-				logger.Debugf("set default source: %s, %s", source.Name, portName)
-				a.ctx.SetSourcePortByIndex(source.Index, portName)
-				a.ctx.SetDefaultSource(source.Name)
-				a.defaultSourceCallback = nil
-				return
-			}
+			logger.Warningf("no profile found for card %s and port %s", card.Name, portName)
+			return ""
 		}
 	}
+	return firstProfile
 }
 
 func (a *Audio) resetSinksVolume() {
@@ -1516,32 +1497,75 @@ func (a *Audio) Reset() *dbus.Error {
 
 	a.resetSinksVolume()
 	a.resetSourceVolume()
-	gsSoundEffect := gio.NewSettings(gsSchemaSoundEffect)
-	gsSoundEffect.Reset(gsKeyEnabled)
-	gsSoundEffect.Unref()
-	return nil
+
+	dconfigSoundEffect, err := dconfig.NewDConfig(dconfigDaemonAppId, dconfigSoundEffectId, "")
+	if err != nil {
+		logger.Warning(err)
+		return dbusutil.ToError(err)
+	}
+
+	return dbusutil.ToError(dconfigSoundEffect.ResetAll())
 }
 
-func (a *Audio) moveSinkInputsToSink(sinkId uint32) {
-	a.mu.Lock()
+func (a *Audio) moveSinkInputsToSink(inputs []uint32) {
 	if len(a.sinkInputs) == 0 {
-		a.mu.Unlock()
 		return
 	}
-	var list []uint32
-	for _, sinkInput := range a.sinkInputs {
-		if sinkInput.getPropSinkIndex() == sinkId {
+
+	sinkName := a.context().GetDefaultSink()
+	if sinkName == "" {
+		return
+	}
+
+	if inputs == nil {
+		inputs = make([]uint32, 0)
+		for _, sinkInput := range a.sinkInputs {
+			inputs = append(inputs, sinkInput.index)
+		}
+	} else {
+		if len(inputs) == 0 {
+			return
+		}
+	}
+
+	var list = make([]uint32, 0)
+	var vrList = make([]uint32, 0)
+	for _, index := range inputs {
+		s, err := a.ctx.GetSinkInput(index)
+		if err != nil {
+			logger.Warning(err)
 			continue
 		}
+		if strings.Contains(s.Name, "Echo-Cancel") || strings.Contains(s.Name, "echo-cancel") {
+			continue
+		} else if strings.Contains(s.Name, "remap-sink-mono") {
+			vrList = append(vrList, index)
+		} else {
+			list = append(list, index)
+		}
+	}
 
-		list = append(list, sinkInput.index)
+	isPhy := isPhysicalDevice(sinkName)
+	if !isPhy {
+		virSink := a.getSinkInfoByName(sinkName)
+		if virSink == nil {
+			logger.Warning("failed to get virtual device sinkInfo for name:", sinkName)
+			return
+		}
+		master := a.getMasterNameFromVirtualDevice(sinkName)
+		if master == "" {
+			logger.Warning("failed to get virtual device sinkInfo for name:", sinkName)
+			return
+		}
+		if len(vrList) > 0 {
+			logger.Infof("will move virtual sink-input %v to sink %s", vrList, master)
+			a.context().MoveSinkInputsByName(vrList, master)
+		}
 	}
-	a.mu.Unlock()
-	if len(list) == 0 {
-		return
+	if len(list) > 0 {
+		logger.Infof("will move sink-input %v to sink %s", list, sinkName)
+		a.context().MoveSinkInputsByName(list, sinkName)
 	}
-	logger.Debugf("move sink inputs %v to sink #%d", list, sinkId)
-	a.ctx.MoveSinkInputsByIndex(list, sinkId)
 }
 
 func isPortExists(name string, ports []pulse.PortInfo) bool {
@@ -1647,7 +1671,7 @@ func (a *Audio) refreshBluetoothOpts() {
 		return
 	}
 	// 云平台无card
-	if a.defaultSink.Card == math.MaxUint32 {
+	if sink.Card == math.MaxUint32 {
 		return
 	}
 	card, err := a.cards.get(sink.Card)
@@ -1695,6 +1719,20 @@ func (a *Audio) updateDefaultSink(sinkName string) {
 		return
 	}
 
+	isPhy := isPhysicalDevice(sinkName)
+	if !isPhy {
+		master := a.getMasterNameFromVirtualDevice(sinkName)
+		if master == "" {
+			logger.Warning("failed to get virtual device sinkInfo for name:", sinkName)
+			return
+		}
+		sinkInfo = a.getSinkInfoByName(master)
+		if sinkInfo == nil {
+			logger.Warning("failed to get virtual device sinkInfo for name:", master)
+			return
+		}
+	}
+
 	// 部分机型defaultSink事件必add事件先上报。
 	// 如果是这种情况触发SinkAdd逻辑再设置默认Sink
 	a.mu.Lock()
@@ -1711,26 +1749,18 @@ func (a *Audio) updateDefaultSink(sinkName string) {
 			return
 		}
 	}
-
-	logger.Debugf("updateDefaultSink #%d %s", sinkInfo.Index, sinkName)
-	a.moveSinkInputsToSink(sinkInfo.Index)
-	if !isPhysicalDevice(sinkName) {
-		master := a.getMasterNameFromVirtualDevice(sinkName)
-		if master == "" {
-			logger.Warning("failed to get virtual device sinkInfo for name:", sinkName)
-			return
-		}
-		sinkInfo = a.getSinkInfoByName(master)
-		if sinkInfo == nil {
-			logger.Warning("failed to get virtual device sinkInfo for name:", master)
-			return
-		}
+	if sink == nil {
+		logger.Warningf("default sink %v not found", sink)
+		return
 	}
 
-	a.defaultSinkName = sinkName
+	logger.Debugf("updateDefaultSink #%d %s", sinkInfo.Index, sinkName)
+	a.moveSinkInputsToSink(nil)
+
+	a.defaultSinkName = sink.Name
 	a.defaultSink = sink
 	defaultSinkPath := sink.getPath()
-	if sink != nil {
+	if isPhy {
 		if err := sink.SetMono(a.Mono); err != nil {
 			logger.Warning(err)
 		}
@@ -1824,17 +1854,6 @@ func (a *Audio) context() *pulse.Context {
 	return c
 }
 
-func (a *Audio) moveSinkInputsToDefaultSink() {
-	a.mu.Lock()
-	if a.defaultSink == nil {
-		a.mu.Unlock()
-		return
-	}
-	defaultSinkIndex := a.defaultSink.index
-	a.mu.Unlock()
-	a.moveSinkInputsToSink(defaultSinkIndex)
-}
-
 func (a *Audio) getDefaultSource() *Source {
 	a.mu.Lock()
 	v := a.defaultSource
@@ -1876,12 +1895,18 @@ func (a *Audio) getDefaultSinkName() string {
 func (a *Audio) getMasterNameFromVirtualDevice(device string) string {
 	modules := a.ctx.GetModuleList()
 	for _, module := range modules {
-		if strings.Contains(module.Name, "echo-cancel") {
+		if strings.Contains(module.Name, "echo-cancel") && strings.Contains(device, "echo-cancel") {
 			re := regexp.MustCompile(`source_master=([^\s]+)`)
 			match := re.FindStringSubmatch(module.Argument)
 			if len(match) > 1 {
 				return match[1]
 			}
+		} else if strings.Contains(module.Name, "module-remap-sink") && strings.Contains(device, "remap-sink") {
+			re := regexp.MustCompile(`sink_master=([^\s]+)`)
+			match := re.FindStringSubmatch(module.Argument)
+			if len(match) > 1 {
+				return match[1]
+			}
 		}
 	}
 	return ""
@@ -1946,6 +1971,58 @@ func (a *Audio) NoRestartPulseAudio() *dbus.Error {
 	return nil
 }
 
+func (a *Audio) StopAudioService() *dbus.Error {
+	service := a.service
+	systemd := systemd1.NewManager(service.Conn())
+	systemd.InitSignalExt(a.sessionSigLoop, true)
+	var audioServices strv.Strv
+	if a.CurrentAudioServer == "pulseaudio" {
+		audioServices = append(audioServices, pulseaudioServices...)
+	} else {
+		audioServices = append(audioServices, pipewireServices...)
+	}
+	var runningServices strv.Strv
+	runningServices = append(runningServices, audioServices...)
+
+	serviceMap := make(map[dbus.ObjectPath]string, 0)
+	var serviceLock sync.Mutex
+	done := make(chan bool, 1)
+	systemd.ConnectJobRemoved(func(jobId uint32, jobPath dbus.ObjectPath, unit string, result string) {
+		serviceLock.Lock()
+		if _, ok := serviceMap[jobPath]; !ok {
+			serviceLock.Unlock()
+			return
+		} else {
+			runningServices, _ = runningServices.Delete(serviceMap[jobPath])
+			logger.Warningf("service %s stopped, %v is running", serviceMap[jobPath], runningServices)
+			if len(runningServices) == 0 {
+				done <- true
+			}
+		}
+		serviceLock.Unlock()
+	})
+	for _, svc := range audioServices {
+		serviceLock.Lock()
+		path, err := systemd.StopUnit(0, svc, "replace")
+		if err != nil {
+			logger.Warning(err)
+			serviceLock.Unlock()
+			continue
+		}
+		serviceMap[path] = svc
+		serviceLock.Unlock()
+	}
+	for {
+		select {
+		case <-done:
+			return nil
+		case <-time.After(3 * time.Second):
+			logger.Warningf("%v is still running, but timeout", runningServices)
+			return dbusutil.ToError(fmt.Errorf("stop audio services timeout"))
+		}
+	}
+}
+
 // 当蓝牙声卡配置文件选择a2dp时,不支持声音输入,所以需要禁用掉,否则会录入
 func (a *Audio) disableBluezSourceIfProfileIsA2dp() {
 	a.mu.Lock()
@@ -1990,6 +2067,10 @@ func (a *Audio) isPortEnabled(cardId uint32, portName string, direction int32) b
 func (a *Audio) SetBluetoothAudioMode(mode string) *dbus.Error {
 	logger.Infof("dbus call SetBluetoothAudioMode with mode %s", mode)
 
+	if a.defaultSink == nil {
+		logger.Warning("default sink is nil")
+		return nil
+	}
 	card, err := a.cards.get(a.defaultSink.Card)
 	if err != nil {
 		logger.Warning(err)
@@ -2013,10 +2094,9 @@ func (a *Audio) SetBluetoothAudioMode(mode string) *dbus.Error {
 		/* 这里需要注意，profile.Available为0表示不可用，非0表示未知 */
 		if profile.Name == mode && profile.Available != 0 {
 			logger.Debugf("set profile %s", profile.Name)
-			// 设置回调函数，当对应的sink/source创建完成后，设置默认sink/source
-			a.setupPortCallback(card.Id, a.defaultSink.ActivePort.Name, pulse.DirectionSink)
 			// 切换配置文件
-			GetConfigKeeper().SetProfile(card.Name, a.defaultSink.ActivePort.Name, profile.Name)
+			GetConfigKeeper().SetPortProfile(card.Name, a.defaultSink.ActivePort.Name, profile.Name)
+			GetConfigKeeper().SetProfile(card.Name, profile.Name)
 			card.core.SetProfile(profile.Name)
 
 			// 手动切换蓝牙模式为headset，Profiles是排序之后的，按照优先级先后来设置
@@ -2036,13 +2116,7 @@ func (a *Audio) setEnableAutoSwitchPort(value bool) {
 	a.enableAutoSwitchPort = value
 	a.PropsMu.Unlock()
 
-	if a.controlCenterGsSettings == nil {
-		return
-	} else if !isStringInSlice(a.controlCenterGsSettings.ListKeys(), gsKeyDeviceManager) {
-		return
-	}
-
-	if a.enableAutoSwitchPort != a.controlCenterDeviceManager.Get() {
+	if a.dccSoundDconfig != nil && a.enableAutoSwitchPort != a.controlCenterDeviceManager.Get() {
 		a.controlCenterDeviceManager.Set(a.enableAutoSwitchPort)
 		logger.Info("setEnableAutoSwitchPort set a.enableAutoSwitchPort to a.controlCenterDeviceManager. value : ", a.enableAutoSwitchPort)
 	}
@@ -2050,113 +2124,70 @@ func (a *Audio) setEnableAutoSwitchPort(value bool) {
 
 // 初始化 dsg 配置的属性
 func (a *Audio) initDsgProp() error {
-	systemBus, err := dbus.SystemBus()
-	if err != nil {
-		return err
-	}
-
-	a.systemSigLoop = dbusutil.NewSignalLoop(systemBus, 10)
-
-	systemConnObj := systemBus.Object("org.desktopspec.ConfigManager", "/")
-	err = systemConnObj.Call("org.desktopspec.ConfigManager.acquireManager", 0, "org.deepin.dde.daemon", "org.deepin.dde.daemon.audio", "").Store(&a.configManagerPath)
+	val, err := a.audioDConfig.GetValueBool(dsgkeyPausePlayer)
 	if err != nil {
 		logger.Warning(err)
-		return nil
 	}
+	a.setEnableAutoSwitchPort(val)
 
-	err = dbusutil.NewMatchRuleBuilder().Type("signal").
-		PathNamespace(string(a.configManagerPath)).
-		Interface("org.desktopspec.ConfigManager.Manager").
-		Member("valueChanged").Build().AddTo(systemBus)
-	if err != nil {
-		logger.Warning(err)
-		return nil
-	}
-
-	var val bool
-	systemConnObj = systemBus.Object("org.desktopspec.ConfigManager", a.configManagerPath)
-	err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, dsgKeyAutoSwitchPort).Store(&val)
+	pausePlayerValue, err := a.audioDConfig.GetValueBool(dsgkeyPausePlayer)
 	if err != nil {
 		logger.Warning(err)
 	} else {
-		logger.Info("auto switch port:", val)
-		a.setEnableAutoSwitchPort(val)
-	}
-
-	var keyPausePlayer bool
-	err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, dsgkeyPausePlayer).Store(&keyPausePlayer)
-	if err != nil {
-		logger.Warning(err)
-	} else {
-		logger.Info("auto switch port:", keyPausePlayer)
+		logger.Info("auto switch port:", pausePlayerValue)
 		a.PropsMu.Lock()
-		a.PausePlayer = keyPausePlayer
+		a.PausePlayer = pausePlayerValue
 		a.PropsMu.Unlock()
 	}
 
-	var ret []dbus.Variant
-	err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, dsgKeyBluezModeFilterList).Store(&ret)
+	bluezModeFilterListValue, err := a.audioDConfig.GetValueStringList(dsgKeyBluezModeFilterList)
 	if err != nil {
 		logger.Warning(err)
 	} else {
 		bluezModeFilterList = bluezModeFilterList[:0]
-		for i := range ret {
-			if v, ok := ret[i].Value().(string); ok {
-				bluezModeFilterList = append(bluezModeFilterList, v)
-			}
-		}
+		bluezModeFilterList = append(bluezModeFilterList, bluezModeFilterListValue...)
 		logger.Info("bluez filter audio mode opts", bluezModeFilterList)
 	}
 
-	err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, dsgKeyPortFilterList).Store(&ret)
+	portFilterListValue, err := a.audioDConfig.GetValueStringList(dsgKeyPortFilterList)
 	if err != nil {
 		logger.Warning(err)
 	} else {
 		portFilterList = portFilterList[:0]
-		for i := range ret {
-			if v, ok := ret[i].Value().(string); ok {
-				portFilterList = append(portFilterList, v)
-			}
-		}
+		portFilterList = append(portFilterList, portFilterListValue...)
 		logger.Info("port filter list", portFilterList)
 	}
 
-	err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, dsgKeyReduceNoise).Store(&defaultReduceNoise)
+	defaultReduceNoiseValue, err := a.audioDConfig.GetValueBool(dsgKeyReduceNoise)
 	if err != nil {
 		logger.Warning(err)
 	} else {
-		logger.Info("default reduce noise status:", defaultReduceNoise)
+		defaultReduceNoise = defaultReduceNoiseValue
+		logger.Info("default reduce noise", defaultReduceNoise)
 	}
 
-	ret = make([]dbus.Variant, 0)
-	err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, dsgKeyInputDefaultPriorities).Store(&ret)
+	inputDefaultPrioritiesValue, err := a.audioDConfig.GetValueInt64List(dsgKeyInputDefaultPriorities)
 	if err != nil {
 		logger.Warning(err)
 	} else {
-		for i := range ret {
-			if v, ok := ret[i].Value().(float64); ok {
-				inputDefaultPriorities = append(inputDefaultPriorities, int(v))
-			}
+		for i := range inputDefaultPrioritiesValue {
+			inputDefaultPriorities = append(inputDefaultPriorities, int(inputDefaultPrioritiesValue[i]))
 		}
 		logger.Info("input default priority list", inputDefaultPriorities)
 	}
 
-	ret = make([]dbus.Variant, 0)
-	err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, dsgKeyOutputDefaultPriorities).Store(&ret)
+	outputDefaultPrioritiesValue, err := a.audioDConfig.GetValueInt64List(dsgKeyOutputDefaultPriorities)
 	if err != nil {
 		logger.Warning(err)
 	} else {
-		for i := range ret {
-			if v, ok := ret[i].Value().(float64); ok {
-				outputDefaultPriorities = append(outputDefaultPriorities, int(v))
-			}
+		for i := range outputDefaultPrioritiesValue {
+			outputDefaultPriorities = append(outputDefaultPriorities, int(outputDefaultPrioritiesValue[i]))
 		}
 		logger.Info("output default priority list", outputDefaultPriorities)
 	}
 
 	getBluezModeDefault := func() {
-		var val string
-		err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, dsgKeyBluezModeDefault).Store(&val)
+		val, err := a.audioDConfig.GetValueString(dsgKeyBluezModeDefault)
 		if err != nil {
 			logger.Warning(err)
 		} else {
@@ -2168,53 +2199,35 @@ func (a *Audio) initDsgProp() error {
 	}
 
 	getMonoEnabled := func() {
-		err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, dsgKeyMonoEnabled).Store(&a.Mono)
+		monoEnabled, err := a.audioDConfig.GetValueBool(dsgKeyMonoEnabled)
 		if err != nil {
 			logger.Warning(err)
+		} else {
+			a.setMono(monoEnabled)
+			logger.Info("mono enabled:", a.Mono)
 		}
 	}
 	getMonoEnabled()
-	// 监听dsg配置变化
-	a.systemSigLoop.AddHandler(&dbusutil.SignalRule{
-		Name: "org.desktopspec.ConfigManager.Manager.valueChanged",
-	}, func(sig *dbus.Signal) {
-		if strings.Contains(sig.Name, "org.desktopspec.ConfigManager.Manager.valueChanged") &&
-			strings.Contains(string(sig.Path), "org_deepin_dde_daemon_audio") && len(sig.Body) >= 1 {
-			key, ok := sig.Body[0].(string)
-			if ok {
-				switch key {
-				case dsgKeyAutoSwitchPort:
-					var val bool
-					err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, key).Store(&val)
-					if err != nil {
-						logger.Warning(err)
-					} else {
-						logger.Info("auto switch port:", val)
-						a.setEnableAutoSwitchPort(val)
-					}
-				case dsgKeyBluezModeDefault:
-					getBluezModeDefault()
-				case dsgkeyPausePlayer:
-					var pausePlayer bool
-					err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, key).Store(&pausePlayer)
-					if err != nil {
-						logger.Warning(err)
-					} else {
-						logger.Info("pausePlayer config:", pausePlayer)
-						a.PropsMu.Lock()
-						a.PausePlayer = pausePlayer
-						a.emitPropChangedPausePlayer(pausePlayer)
-						a.PropsMu.Unlock()
-					}
-				case dsgKeyMonoEnabled:
-					getMonoEnabled()
-				}
-			}
+
+	a.audioDConfig.ConnectValueChanged(func(key string) {
+		switch key {
+		case dsgKeyAutoSwitchPort:
+			value, _ := a.audioDConfig.GetValueBool(dsgKeyAutoSwitchPort)
+			logger.Info("auto switch port:", value)
+			a.setEnableAutoSwitchPort(value)
+		case dsgKeyBluezModeDefault:
+			getBluezModeDefault()
+		case dsgkeyPausePlayer:
+			pausePlayer, _ := a.audioDConfig.GetValueBool(dsgkeyPausePlayer)
+			logger.Info("pausePlayer config:", pausePlayer)
+			a.emitPropChangedPausePlayer(pausePlayer)
+		case dsgKeyMonoEnabled:
+			getMonoEnabled()
+		case dsgKeyVolumeIncrease:
+			a.handleVolumeIncrease()
 		}
 	})
 
-	a.systemSigLoop.Start()
-
 	return nil
 }
 
@@ -2242,14 +2255,34 @@ func (a *Audio) setMono(enable bool) error {
 	}
 
 	a.setPropMono(enable)
-	systemBus, err := dbus.SystemBus()
-	if err != nil {
-		return dbus.MakeFailedError(err)
-	}
-	systemConnObj := systemBus.Object("org.desktopspec.ConfigManager", a.configManagerPath)
-	err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.setValue", 0, dsgKeyMonoEnabled, dbus.MakeVariant(enable)).Err
+	err := a.audioDConfig.SetValue(dsgKeyMonoEnabled, enable)
 	if err != nil {
 		return dbusutil.ToError(errors.New("dconfig Cannot set value " + dsgKeyMonoEnabled))
 	}
 	return nil
 }
+
+func (a *Audio) handleVolumeIncrease() {
+	volInc, err := a.audioDConfig.GetValueBool(dsgKeyVolumeIncrease)
+	if err != nil {
+		logger.Warning("dconfig get volume increase error:", err)
+		return
+	}
+	if volInc {
+		a.MaxUIVolume = increaseMaxVolume
+	} else {
+		a.MaxUIVolume = normalMaxVolume
+	}
+	gMaxUIVolume = a.MaxUIVolume
+	err = a.emitPropChangedMaxUIVolume(a.MaxUIVolume)
+	if err != nil {
+		logger.Warning("changed Max UI Volume failed: ", err)
+	} else {
+		sink := a.getDefaultSink()
+		if sink == nil {
+			logger.Warning("default sink is nil")
+			return
+		}
+		GetConfigKeeper().SetIncreaseVolume(a.getCardNameById(sink.Card), sink.ActivePort.Name, volInc)
+	}
+}
