@@ -15,7 +15,6 @@ import (
 	notifications "github.com/linuxdeepin/go-dbus-factory/session/org.freedesktop.notifications"
 	"github.com/linuxdeepin/go-lib/dbusutil"
 	"github.com/linuxdeepin/go-lib/gettext"
-	"github.com/linuxdeepin/go-lib/gsettings"
 	"github.com/linuxdeepin/go-lib/pulse"
 )
 
@@ -131,20 +130,6 @@ func (a *Audio) needAutoSwitchInputPort() bool {
 		return false
 	}
 
-	// 当前端口为空
-	if a.defaultSource == nil {
-		logger.Debug("current source is nil")
-		return true
-	}
-
-	// 设置端口时，不触发自动切换
-	a.callbackLocker.Lock()
-	if a.defaultSourceCallback != nil {
-		logger.Warning("default source callback is not nil, wait for callback")
-		a.callbackLocker.Unlock()
-		return false
-	}
-	a.callbackLocker.Unlock()
 	// 检查当前profile是否是配置文件中设置的profile
 	card, err := a.cards.getByName(firstPort.CardName)
 	if err != nil {
@@ -158,6 +143,21 @@ func (a *Audio) needAutoSwitchInputPort() bool {
 		logger.Warningf("output profile not match, current: %s, prefer: %s", cp.Name, profile)
 		return false
 	}
+	// 如果port的配置文件和profile也不能自动切换
+	found := false
+	port, err := card.Ports.Get(firstPort.PortName, pulse.DirectionSource)
+	if err != nil {
+		logger.Warning(err)
+		return false
+	}
+	for _, pp := range port.Profiles {
+		if pp.Available != 0 && pp.Name == profile {
+			found = true
+		}
+	}
+	if !found {
+		return false
+	}
 
 	// 同端口切换次数超出限制(切换失败时反复切换同一端口)
 	if a.inputAutoSwitchCount >= 10 &&
@@ -167,8 +167,12 @@ func (a *Audio) needAutoSwitchInputPort() bool {
 	}
 
 	// 当前端口就是优先级最高的端口
-	currentCardName := a.getCardNameById(a.defaultSource.Card)
-	currentPortName := a.defaultSource.ActivePort.Name
+	var currentCardName, currentPortName string
+	if a.defaultSource != nil {
+		currentCardName = a.getCardNameById(a.defaultSource.Card)
+		currentPortName = a.defaultSource.ActivePort.Name
+	}
+
 	if currentCardName == firstPort.CardName && currentPortName == firstPort.PortName {
 		logger.Debugf("current input<%s,%s> is already the first port",
 			currentCardName, currentPortName)
@@ -180,12 +184,95 @@ func (a *Audio) needAutoSwitchInputPort() bool {
 	return true
 }
 
+func (a *Audio) autoSwitchOutputPort() error {
+	// 不支持自动切换端口
+	if !a.canAutoSwitchPort() {
+		return nil
+	}
+	logger.Debug("auto switch output")
+	firstPort := a.tryGetPreferOutPut()
+
+	// 没有可用端口
+	if firstPort.PortType == PortTypeInvalid {
+		return fmt.Errorf("no output port")
+	}
+
+	// 检查当前profile是否是配置文件中设置的profile
+	card, err := a.cards.getByName(firstPort.CardName)
+	if err != nil {
+		return err
+	}
+	cp := card.core.ActiveProfile
+	profile := GetConfigKeeper().GetCardPreferProfile(card.core.Name)
+	preferPort := GetConfigKeeper().GetCardPreferPort(card.core.Name)
+	// 如果优选的端口和期望的配置文件、期望的端口匹配都可以触发切换
+	if profile != "" &&
+		cp.Name != profile &&
+		firstPort.PortName != preferPort {
+		return fmt.Errorf("output profile not match, current: %s, prefer: %s,firstPort: %s, preferPort: %s", cp.Name, profile, firstPort.PortName, preferPort)
+	}
+
+	var currentCardName, currentPortName string
+	if a.defaultSink != nil {
+		currentCardName = a.getCardNameById(a.defaultSink.Card)
+		currentPortName = a.defaultSink.ActivePort.Name
+	}
+
+	if currentCardName == firstPort.CardName && currentPortName == firstPort.PortName {
+		logger.Debugf("current output<%s,%s> is already the first",
+			currentCardName, currentPortName)
+		return nil
+	}
+
+	logger.Debugf("will auto switch from output<%s,%s> to output<%s,%s>",
+		currentCardName, currentPortName, firstPort.CardName, firstPort.PortName)
+	return a.setPort(card.Id, firstPort.PortName, pulse.DirectionSink, true)
+}
+
+func (a *Audio) autoSwitchInputPort() error {
+	// 不支持自动切换端口
+	if !a.canAutoSwitchPort() {
+		return nil
+	}
+
+	// 当前端口就是优先级最高的端口
+	var currentCardName, currentPortName string
+	if a.defaultSource != nil {
+		currentCardName = a.getCardNameById(a.defaultSource.Card)
+		currentPortName = a.defaultSource.ActivePort.Name
+	}
+
+	for _, input := range GetPriorityManager().Input.Ports {
+		cc, pc := GetConfigKeeper().GetCardAndPortConfig(input.CardName, input.PortName)
+		if !pc.Enabled {
+			continue
+		}
+		card, err := a.cards.getByName(cc.Name)
+		if err != nil {
+			logger.Warning(err)
+			continue
+		}
+		cp := card.core.ActiveProfile
+		port, err := card.Ports.Get(pc.Name, pulse.DirectionSource)
+		if err != nil {
+			logger.Warning(err)
+			continue
+		}
+		if port.Profiles.Exists(cp.Name) {
+			logger.Debugf("will auto switch from input<%s,%s> to input<%s,%s>",
+				currentCardName, currentPortName, cc.Name, pc.Name)
+			return a.setPort(card.Id, pc.Name, pulse.DirectionSource, true)
+		}
+	}
+	return nil
+}
+
 func (a *Audio) needAutoSwitchOutputPort() bool {
 	// 不支持自动切换端口
 	if !a.canAutoSwitchPort() {
 		return false
 	}
-
+	logger.Debug("check need auto switch output")
 	firstPort := a.tryGetPreferOutPut()
 
 	// 没有可用端口
@@ -194,20 +281,6 @@ func (a *Audio) needAutoSwitchOutputPort() bool {
 		return false
 	}
 
-	// 当前端口为空
-	if a.defaultSink == nil {
-		logger.Debug("default sink is nil")
-		return true
-	}
-
-	// 设置端口时，不触发自动切换
-	a.callbackLocker.Lock()
-	if a.defaultSinkCallback != nil {
-		logger.Warning("default sink callback is not nil, wait for callback")
-		a.callbackLocker.Unlock()
-		return false
-	}
-	a.callbackLocker.Unlock()
 	// 检查当前profile是否是配置文件中设置的profile
 	card, err := a.cards.getByName(firstPort.CardName)
 	if err != nil {
@@ -221,16 +294,13 @@ func (a *Audio) needAutoSwitchOutputPort() bool {
 		return false
 	}
 
-	// 同端口切换次数超出限制(切换失败时反复切换同一端口)
-	if a.outputAutoSwitchCount >= a.outputAutoSwitchCountMax &&
-		(a.outputCardName == firstPort.CardName && a.outputPortName == firstPort.PortName) {
-		logger.Debug("output auto switch tried too many times")
-		return false
+	// 当前端口就是优先级最高的端口
+	var currentCardName, currentPortName string
+	if a.defaultSink != nil {
+		currentCardName = a.getCardNameById(a.defaultSink.Card)
+		currentPortName = a.defaultSink.ActivePort.Name
 	}
 
-	// 当前端口就是优先级最高的端口
-	currentCardName := a.getCardNameById(a.defaultSink.Card)
-	currentPortName := a.defaultSink.ActivePort.Name
 	if currentCardName == firstPort.CardName && currentPortName == firstPort.PortName {
 		logger.Debugf("current output<%s,%s> is already the first",
 			currentCardName, currentPortName)
@@ -242,74 +312,25 @@ func (a *Audio) needAutoSwitchOutputPort() bool {
 	return true
 }
 
-func (a *Audio) autoSwitchProfile(card *Card) {
-	profile := GetConfigKeeper().GetCardPreferProfile(card.core.Name)
-	if profile == "" {
-		return
-	}
-
-	cp := card.core.ActiveProfile
-	if cp.Name == profile {
-		return
-	}
-	logger.Debugf("auto switch profile %s to %s", cp.Name, profile)
-	card.core.SetProfile(profile)
-}
-
 // 自动切换端口，至少要保证声卡的profile是配置文件中设置的profile
 // 如果不是，可能还在切换中，等待一下
 func (a *Audio) autoSwitchPort() {
 	logger.Warning("auto switch port")
-	if a.needAutoSwitchOutputPort() {
-		firstOutput := a.tryGetPreferOutPut()
-		card, err := a.cards.getByName(firstOutput.CardName)
-
-		if err == nil {
-			logger.Warningf("auto switch output to #%d %s:%s", card.Id, card.core.Name, firstOutput.PortName)
-			a.setPort(card.Id, firstOutput.PortName, pulse.DirectionSink)
-		} else {
-			logger.Warning(err)
-		}
-
-		// 自动切换计数
-		if a.outputCardName == firstOutput.CardName && a.outputPortName == firstOutput.PortName {
-			a.outputAutoSwitchCount++
-		} else {
-			a.outputAutoSwitchCount = 0
-			a.outputCardName = firstOutput.CardName
-			a.outputPortName = firstOutput.PortName
-		}
+	if err := a.autoSwitchOutputPort(); err != nil {
+		logger.Warning(err)
 	}
-
-	if a.needAutoSwitchInputPort() {
-		logger.Warning("auto switch input")
-		inputs := GetPriorityManager().Input
-		firstInput := inputs.GetTheFirstPort()
-		card, err := a.cards.getByName(firstInput.CardName)
-
-		if err == nil {
-			logger.Debugf("auto switch input to #%d %s:%s", card.Id, card.core.Name, firstInput.PortName)
-			a.setPort(card.Id, firstInput.PortName, pulse.DirectionSource)
-		} else {
-			logger.Warning(err)
-		}
-
-		// 自动切换计数
-		if a.inputCardName == firstInput.CardName && a.inputPortName == firstInput.PortName {
-			a.inputAutoSwitchCount++
-		} else {
-			a.inputAutoSwitchCount = 0
-			a.inputCardName = firstInput.CardName
-			a.inputPortName = firstInput.PortName
-		}
+	if err := a.autoSwitchInputPort(); err != nil {
+		logger.Warning(err)
 	}
 }
 
 func (a *Audio) handleCardEvent(eventType int, idx uint32) {
 	switch eventType {
 	case pulse.EventTypeNew: // 新增声卡
+		a.autoPause()
 		a.handleCardAdded(idx)
 	case pulse.EventTypeRemove: // 删除声卡
+		a.autoPause()
 		a.handleCardRemoved(idx)
 	case pulse.EventTypeChange: // 声卡属性变化,也可能是有线耳机插拔了端口
 		a.handleCardChanged(idx)
@@ -317,20 +338,8 @@ func (a *Audio) handleCardEvent(eventType int, idx uint32) {
 		logger.Warningf("unhandled card event, card=%d, type=%d", idx, eventType)
 	}
 
-	// 这里写所有类型的card事件都需要触发的逻辑
-	/* 新增声卡上的端口如果被处于禁用状态，进行横幅提示 */
-	card, err := a.cards.get(idx)
-	if err == nil {
-		if isBluezAudio(card.core.Name) {
-			logger.Debugf("notify bluez card %s", card.core.Name)
-			a.notifyBluezCardPortInsert(card)
-		} else {
-			logger.Debugf("notify normal card %s", card.core.Name)
-			a.notifyCardPortInsert(card)
-		}
-	} else {
-		logger.Warning(err)
-	}
+	// 保存旧的cards
+	a.oldCards = a.cards
 }
 
 func (a *Audio) handleCardAdded(idx uint32) {
@@ -347,12 +356,20 @@ func (a *Audio) handleCardAdded(idx uint32) {
 	a.setPropCards(cards)
 	a.setPropCardsWithoutUnavailable(a.cards.stringWithoutUnavailable())
 
-	// 保存旧的cards
-	a.oldCards = a.cards
 	GetPriorityManager().SetPorts(a.cards)
 	GetPriorityManager().Save()
 
-	a.autoSwitchProfile(ac)
+	// 这里写所有类型的card事件都需要触发的逻辑
+	/* 新增声卡上的端口如果被处于禁用状态，进行横幅提示 */
+	if isBluezAudio(card.Name) {
+		logger.Debugf("notify bluez card %s", card.Name)
+		a.notifyBluezCardPortInsert(ac)
+	} else {
+		logger.Debugf("notify normal card %s", card.Name)
+		a.notifyCardPortInsert(ac)
+	}
+
+	a.autoSwitchPort()
 }
 
 func (a *Audio) handleCardRemoved(idx uint32) {
@@ -364,7 +381,10 @@ func (a *Audio) handleCardRemoved(idx uint32) {
 	a.setPropCards(cards)
 	a.setPropCardsWithoutUnavailable(a.cards.stringWithoutUnavailable())
 
-	a.autoSwitchPort()
+	if a.defaultSink == nil || a.defaultSink.Card == idx || a.defaultSource.Card == idx {
+		logger.Debugf("card %d is default sink or source, auto switch port", idx)
+		a.autoSwitchPort()
+	}
 }
 
 func (a *Audio) handleCardChanged(idx uint32) {
@@ -382,6 +402,7 @@ func (a *Audio) handleCardChanged(idx uint32) {
 	}
 
 	oldPorts := ac.Ports
+	oldProfile := ac.ActiveProfile
 
 	ac.core = pc
 	ac.update(pc)
@@ -390,10 +411,22 @@ func (a *Audio) handleCardChanged(idx uint32) {
 	a.setPropCards(cards)
 	a.setPropCardsWithoutUnavailable(a.cards.stringWithoutUnavailable())
 
+	GetPriorityManager().SetPorts(a.cards)
+	GetPriorityManager().Save()
+
+	if oldProfile.Name != ac.ActiveProfile.Name {
+		logger.Infof("card profile change from %v to %v", oldProfile.Name, ac.ActiveProfile.Name)
+	}
 	// 如果端口发生变化，则需要自动切换端口
 	if len(oldPorts) != len(ac.Ports) {
+		logger.Debug("card port changed")
+		logger.Debugf("card old ports=%+v", oldPorts)
+		logger.Debugf("card old newPorts=%+v", ac.Ports)
 		a.autoSwitchPort()
-	} else {
+	} else if !isBluezAudio(ac.Name) {
+		// 蓝牙声卡不检查状态
+		// 因为蓝牙声卡会处理a2dp模式，会导致端口状态对不上
+		shouldAutoSwitch := false
 		for _, port := range oldPorts {
 			p, err := ac.Ports.Get(port.Name, port.Direction)
 			if err != nil {
@@ -401,10 +434,20 @@ func (a *Audio) handleCardChanged(idx uint32) {
 				continue
 			}
 			if p.Available != port.Available {
-				a.autoSwitchPort()
-				break
+				logger.Debugf("card port available changed, %v.%v from %v to %v",
+					pc.Name, port.Name, port.Available, p.Available)
+				_, portConfig := GetConfigKeeper().GetCardAndPortConfig(pc.Name, port.Name)
+				logger.Warningf("portConfig: %+v", portConfig)
+				if !portConfig.Enabled && p.Available != pulse.AvailableTypeNo {
+					logger.Debugf("port<%s,%s> notify", ac.Name, port.Name)
+					a.notifyPortDisabled(ac.Id, port)
+				}
+				shouldAutoSwitch = true
 			}
 		}
+		if shouldAutoSwitch {
+			a.autoSwitchPort()
+		}
 	}
 }
 
@@ -425,12 +468,12 @@ func (a *Audio) handleSinkEvent(eventType int, idx uint32) {
 
 func (a *Audio) handleSinkAdded(idx uint32) {
 	// 数据更新在refreshSinks中统一处理，这里只做业务逻辑上的响应
-	logger.Debugf("sink %d added", idx)
 	sink, err := a.ctx.GetSink(idx)
 	if err != nil {
 		logger.Warning(err)
 		return
 	}
+	logger.Debugf("sink %d %s added", idx, sink.Name)
 	if sink.Name == dndVirtualSinkName {
 		port := pulse.PortInfo{
 			Name:        sink.Name,
@@ -448,34 +491,8 @@ func (a *Audio) handleSinkAdded(idx uint32) {
 		a.addSink(sink)
 	}
 
-	a.callbackLocker.Lock()
-	if a.defaultSinkCallback != nil {
-		a.defaultSinkCallback(sink)
-		a.callbackLocker.Unlock()
-		return
-	}
-	a.callbackLocker.Unlock()
-
-	if a.needAutoSwitchOutputPort() {
-		logger.Info("auto switch output")
-		firstOutput := a.tryGetPreferOutPut()
-		card, err := a.cards.getByName(firstOutput.CardName)
-
-		if err == nil {
-			logger.Warningf("auto switch output to #%d %s:%s", card.Id, card.core.Name, firstOutput.PortName)
-			a.setPort(card.Id, firstOutput.PortName, pulse.DirectionSink)
-		} else {
-			logger.Warning(err)
-		}
-
-		// 自动切换计数
-		if a.outputCardName == firstOutput.CardName && a.outputPortName == firstOutput.PortName {
-			a.outputAutoSwitchCount++
-		} else {
-			a.outputAutoSwitchCount = 0
-			a.outputCardName = firstOutput.CardName
-			a.outputPortName = firstOutput.PortName
-		}
+	if err := a.autoSwitchOutputPort(); err != nil {
+		logger.Warning(err)
 	}
 }
 
@@ -488,6 +505,12 @@ func (a *Audio) handleSinkRemoved(idx uint32) {
 		delete(a.sinks, idx)
 	}
 	a.updatePropSinks()
+	if a.defaultSink != nil && a.defaultSink.index == idx {
+		logger.Debugf("set default sink to / because of sink removed")
+		a.setPropDefaultSink("/")
+		a.defaultSinkName = ""
+		a.defaultSink = nil
+	}
 }
 
 func (a *Audio) handleSinkChanged(idx uint32) {
@@ -536,37 +559,8 @@ func (a *Audio) handleSourceAdded(idx uint32) {
 	}
 	a.updatePropSources()
 
-	// TODO: 恢复配置？
-
-	a.callbackLocker.Lock()
-	if a.defaultSourceCallback != nil {
-		a.defaultSourceCallback(source)
-		a.callbackLocker.Unlock()
-		return
-	}
-	a.callbackLocker.Unlock()
-
-	if a.needAutoSwitchInputPort() {
-		logger.Warning("auto switch input")
-		inputs := GetPriorityManager().Input
-		firstInput := inputs.GetTheFirstPort()
-		card, err := a.cards.getByName(firstInput.CardName)
-
-		if err == nil {
-			logger.Debugf("auto switch input to #%d %s:%s", card.Id, card.core.Name, firstInput.PortName)
-			a.setPort(card.Id, firstInput.PortName, pulse.DirectionSource)
-		} else {
-			logger.Warning(err)
-		}
-
-		// 自动切换计数
-		if a.inputCardName == firstInput.CardName && a.inputPortName == firstInput.PortName {
-			a.inputAutoSwitchCount++
-		} else {
-			a.inputAutoSwitchCount = 0
-			a.inputCardName = firstInput.CardName
-			a.inputPortName = firstInput.PortName
-		}
+	if err := a.autoSwitchInputPort(); err != nil {
+		logger.Warning(err)
 	}
 }
 
@@ -579,6 +573,12 @@ func (a *Audio) handleSourceRemoved(idx uint32) {
 		delete(a.sources, idx)
 	}
 	a.updatePropSources()
+	if a.defaultSource != nil && a.defaultSource.index == idx {
+		logger.Warning("set default source to / because of source removed")
+		a.setPropDefaultSource("/")
+		a.defaultSourceName = ""
+		a.defaultSource = nil
+	}
 }
 
 func (a *Audio) handleSourceChanged(idx uint32) {
@@ -612,17 +612,22 @@ func (a *Audio) handleSinkInputEvent(eventType int, idx uint32) {
 
 func (a *Audio) handleSinkInputAdded(idx uint32) {
 	// 数据更新在refreshSinkInputs中统一处理，这里只做业务逻辑上的响应
-	logger.Debugf("sink-input %d added", idx)
 	sinkInput, err := a.ctx.GetSinkInput(idx)
 	if err != nil {
 		logger.Warning(err)
 		return
 	}
+	logger.Debugf("sink-input %d %s added", idx, sinkInput.Name)
 	if _, exist := a.sinkInputs[idx]; exist {
 		a.sinkInputs[idx].update(sinkInput)
 	} else {
 		a.addSinkInput(sinkInput)
 	}
+	if a.defaultSink != nil {
+		list := []uint32{idx}
+		logger.Infof("move sink-input %d to default sink", idx)
+		a.moveSinkInputsToSink(list)
+	}
 }
 
 func (a *Audio) handleSinkInputRemoved(idx uint32) {
@@ -738,7 +743,7 @@ func (a *Audio) updatePropSinkInputs() {
 
 func isPhysicalDevice(deviceName string) bool {
 	for _, virtualDeviceKey := range []string{
-		"echoCancelSource", "echo-cancel", "Echo-Cancel", // virtual key
+		"echoCancelSource", "echo-cancel", "Echo-Cancel", "remap-sink-mono", // virtual key
 	} {
 		if strings.Contains(deviceName, virtualDeviceKey) {
 			return false
@@ -762,34 +767,6 @@ func (a *Audio) handleServerEvent(eventType int) {
 	}
 }
 
-func (a *Audio) listenGSettingVolumeIncreaseChanged() {
-	gsettings.ConnectChanged(gsSchemaAudio, gsKeyVolumeIncrease, func(val string) {
-		volInc := a.settings.GetBoolean(gsKeyVolumeIncrease)
-		if volInc {
-			a.MaxUIVolume = increaseMaxVolume
-		} else {
-			a.MaxUIVolume = normalMaxVolume
-		}
-		gMaxUIVolume = a.MaxUIVolume
-		err := a.emitPropChangedMaxUIVolume(a.MaxUIVolume)
-		if err != nil {
-			logger.Warning("changed Max UI Volume failed: ", err)
-		} else {
-			sink := a.defaultSink
-			GetConfigKeeper().SetIncreaseVolume(a.getCardNameById(sink.Card), sink.ActivePort.Name, volInc)
-		}
-	})
-}
-
-func (a *Audio) listenGSettingDeviceManageChanged() {
-	gsettings.ConnectChanged(gsSchemaControlCenter, gsKeyDeviceManager, func(val string) {
-		if a.enableAutoSwitchPort != a.controlCenterDeviceManager.Get() {
-			a.controlCenterDeviceManager.Set(a.enableAutoSwitchPort)
-			logger.Info("listenGSettingDeviceManageChanged set a.enableAutoSwitchPort to a.controlCenterDeviceManager. value : ", a.enableAutoSwitchPort)
-		}
-	})
-}
-
 // 外部修改ReducecNoise时触发回调，响应实际降噪开关
 func (a *Audio) writeReduceNoise(write *dbusutil.PropertyWrite) *dbus.Error {
 	reduce, ok := write.Value.(bool)
@@ -800,7 +777,7 @@ func (a *Audio) writeReduceNoise(write *dbusutil.PropertyWrite) *dbus.Error {
 		return nil
 	}
 
-	if reduce && isBluezAudio(a.defaultSource.Name) {
+	if reduce && a.defaultSource != nil && isBluezAudio(a.defaultSource.Name) {
 		logger.Debug("bluetooth audio device cannot open reduce-noise")
 		a.ReduceNoise = false
 		a.emitPropChangedReduceNoise(a.ReduceNoise)
@@ -828,22 +805,7 @@ func (a *Audio) writeReduceNoise(write *dbusutil.PropertyWrite) *dbus.Error {
 }
 
 func (a *Audio) writeKeyPausePlayer(write *dbusutil.PropertyWrite) *dbus.Error {
-	pausePlayer, ok := write.Value.(bool)
-	if !ok {
-		return dbusutil.ToError(errors.New("type is not bool"))
-	}
-	systemBus, err := dbus.SystemBus()
-	if err != nil {
-		return dbus.MakeFailedError(err)
-	}
-
-	systemConnObj := systemBus.Object("org.desktopspec.ConfigManager", a.configManagerPath)
-	err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.setValue", 0, dsgkeyPausePlayer, dbus.MakeVariant(pausePlayer)).Err
-	if err != nil {
-		return dbusutil.ToError(errors.New("dconfig Cannot set value " + dsgkeyPausePlayer))
-	}
-	a.setPropPausePlayer(pausePlayer)
-	return nil
+	return dbusutil.ToError(a.audioDConfig.SetValue(dsgkeyPausePlayer, write.Value))
 }
 
 func (a *Audio) notifyBluezCardPortInsert(card *Card) {
@@ -854,12 +816,6 @@ func (a *Audio) notifyBluezCardPortInsert(card *Card) {
 		logger.Warning(err)
 	}
 
-	// 蓝牙模式配置出错情况过滤通知
-	if card.ActiveProfile.Name == "off" {
-		logger.Debugf("filter bluez notify, beacuse profile is off")
-		return
-	}
-
 	// 蓝牙会根据模式过滤端口，因此忽略unknown状态
 	for _, port := range card.Ports {
 		if port.Available == pulse.AvailableTypeNo {
