@@ -5,13 +5,12 @@
 package main
 
 import (
-	configManager "github.com/linuxdeepin/go-dbus-factory/org.desktopspec.ConfigManager"
 	"os"
 
+	configManager "github.com/linuxdeepin/go-dbus-factory/org.desktopspec.ConfigManager"
+
 	// modules:
 	_ "github.com/linuxdeepin/dde-daemon/accounts1"
-	_ "github.com/linuxdeepin/dde-daemon/apps1"
-	_ "github.com/linuxdeepin/dde-daemon/fprintd1"
 	_ "github.com/linuxdeepin/dde-daemon/image_effect1"
 	_ "github.com/linuxdeepin/dde-daemon/system/airplane_mode1"
 	_ "github.com/linuxdeepin/dde-daemon/system/bluetooth1"
@@ -21,7 +20,6 @@ import (
 	_ "github.com/linuxdeepin/dde-daemon/system/inputdevices1"
 	_ "github.com/linuxdeepin/dde-daemon/system/keyevent1"
 	_ "github.com/linuxdeepin/dde-daemon/system/lang"
-	_ "github.com/linuxdeepin/dde-daemon/system/network1"
 	_ "github.com/linuxdeepin/dde-daemon/system/power1"
 	_ "github.com/linuxdeepin/dde-daemon/system/power_manager1"
 	_ "github.com/linuxdeepin/dde-daemon/system/resource_ctl"
