@@ -623,7 +623,7 @@ func checkInvokePermission(service *dbusutil.Service, sender dbus.Sender) error
 			return err
 		}
 		p := procfs.Process(pid)
-		cmd, err := p.TrustedExe()
+		cmd, err := p.Exe()
 		if err != nil {
 			// 当调用者在使用过程中发生了更新,则在获取该进程的exe时,会出现lstat xxx (deleted)此类的error,如果发生的是覆盖,则该路径依旧存在,因此增加以下判断
 			pErr, ok := err.(*os.PathError)
