@@ -24,10 +24,6 @@ type Theme struct {
 	}
 }
 
-func (*Theme) GetInterfaceName() string {
-	return themeDBusInterface
-}
-
 // NewTheme create Theme object.
 func NewTheme(g *Grub2) *Theme {
 	theme := &Theme{}
