@@ -1,24 +1,24 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ast" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ast">
 	<context>
 		<name>policy</name>
 		<message>
 			<location filename="org.deepin.dde.grub2!message" line="0"/>
-			<source>Authentication is required to change the grub2 configuration</source>
-			<translation>Ríquese l&apos;autenticación pa camudar la configuración de GRUB</translation>
+			<source>Authentication is required to change the grub configuration</source>
+			<translation type="unfinished"/>
 		</message>
 		<message>
 			<location filename="org.deepin.dde.grub2!description" line="0"/>
-			<source>Change the grub2 configuration</source>
-			<translation>Cambéu de la configuración de GRUB</translation>
+			<source>Change the grub configuration</source>
+			<translation type="unfinished"/>
 		</message>
 		<message>
 			<location filename="org.deepin.dde.grub2.prepare-gfxmode-detect!message" line="0"/>
-			<source>Authentication is required to prepare grub2 display resolution detection</source>
+			<source>Authentication is required to prepare grub display resolution detection</source>
 			<translation type="unfinished"/>
 		</message>
 		<message>
 			<location filename="org.deepin.dde.grub2.prepare-gfxmode-detect!description" line="0"/>
-			<source>Prepare grub2 display resolution detection</source>
+			<source>Prepare grub display resolution detection</source>
 			<translation type="unfinished"/>
 		</message>
 	</context>
