@@ -9,3 +9,7 @@ func Tr(in string) string {
 }
 
 var _ = Tr("\"%s\" did not pass the system security verification, and cannot run now")
+
+var _ = Tr("You cannot run the unverified \"%s\", but you can change the settings in Security Center.")
+
+var _ = Tr("Proceed")
