@@ -8,7 +8,6 @@ import (
 	"time"
 
 	"github.com/linuxdeepin/go-lib/dbusutil"
-	"github.com/linuxdeepin/go-lib/gsettings"
 	"github.com/linuxdeepin/go-lib/log"
 )
 
@@ -25,8 +24,6 @@ func run() error {
 		return err
 	}
 
-	_ = gsettings.StartMonitor()
-
 	serverObj, err := service.NewServerObject(dbusPath, m)
 	if err != nil {
 		return err
