@@ -5,7 +5,7 @@
 package power_manager
 
 import (
-	"io/ioutil"
+	"os"
 	"os/exec"
 	"strings"
 )
@@ -19,7 +19,7 @@ func canSuspend() bool {
 	// 等到内核对systemd的login中判断是否能待机的DBus接口(服务名 org.freedesktop.login1，
 	// 对象 /org/freedesktop/login1，接口 org.freedesktop.login1.Manager 方法 CanSuspend)
 	// 支持完善以后就要移除这部分逻辑。
-	data, err := ioutil.ReadFile(fileMemSleep)
+	data, err := os.ReadFile(fileMemSleep)
 	if err != nil {
 		logger.Warningf("read %s failed: %v", fileMemSleep, err)
 		return false
@@ -33,7 +33,7 @@ func canSuspend() bool {
 }
 
 func detectVirtualMachine() (string, error) {
-	out, err := exec.Command("systemd-detect-virt").Output()
+	out, err := exec.Command("/usr/bin/systemd-detect-virt").Output()
 	if err != nil {
 		return "", err
 	}
