@@ -355,8 +355,9 @@ func (m *Manager) handleXEvent() {
 					if m.hideCursorWhenTouch {
 						m.beginMoveMouse()
 					}
-
+					m.mu.Lock()
 					_, ok := m.idReferCountMap[fullscreenId]
+					m.mu.Unlock()
 					if len(m.idAreaInfoMap) == 0 && !ok {
 						break
 					}
